summaryrefslogtreecommitdiffstats
path: root/knetworkconf/knetworkconf/knetworkconfigparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'knetworkconf/knetworkconf/knetworkconfigparser.h')
-rw-r--r--knetworkconf/knetworkconf/knetworkconfigparser.h80
1 files changed, 40 insertions, 40 deletions
diff --git a/knetworkconf/knetworkconf/knetworkconfigparser.h b/knetworkconf/knetworkconf/knetworkconfigparser.h
index 0c2254e..f0af15f 100644
--- a/knetworkconf/knetworkconf/knetworkconfigparser.h
+++ b/knetworkconf/knetworkconf/knetworkconfigparser.h
@@ -33,14 +33,14 @@
#include <kapp.h>
#include <kmessagebox.h>
#include <klocale.h>
-#include <qobject.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qstring.h>
-#include <qprocess.h>
-#include <qdom.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
+#include <tqobject.h>
+#include <tqdir.h>
+#include <tqfile.h>
+#include <tqstring.h>
+#include <tqprocess.h>
+#include <tqdom.h>
+#include <tqlabel.h>
+#include <tqcheckbox.h>
#include <klistbox.h>
#include <ksimpleconfig.h>
@@ -57,14 +57,14 @@
*@author Juan Luis Baptiste
*/
-class KNetworkConfigParser : public QObject {
+class KNetworkConfigParser : public TQObject {
Q_OBJECT
public:
KNetworkConfigParser();
~KNetworkConfigParser();
/** return tyhe number of configured devices. */
unsigned numDevices();
- void setProgramVersion(QString ver);
+ void setProgramVersion(TQString ver);
/** Reads /proc/net/route looking for the default gateway. */
void loadRoutingInfo(KRoutingInfo *routingInfo);
/** Saves the new network configuration. */
@@ -72,28 +72,28 @@ class KNetworkConfigParser : public QObject {
/** Loads the network info from a xml file generated by the gnome system tools
network backends that are included with this app. */
KNetworkInfo * getNetworkInfo();
- QProcess * proc;
- QProcess * procDetect;
- QProcess * procSaveNetworkInfo;
+ TQProcess * proc;
+ TQProcess * procDetect;
+ TQProcess * procSaveNetworkInfo;
/** Variable to know if there is an dhcp device configured, so we can know if we need to save the defauilt gw info or not. */
bool dhcpDevice;
- KNetworkInterface * getDeviceInfo(QString device);
+ KNetworkInterface * getDeviceInfo(TQString device);
public slots:
/** runs gst to find out the state of network devices.It runs the command:
$knetworkconf_home/backends/networkconf [--platform platform] -d list_ifaces */
- void listIfaces(const QString &platform);
+ void listIfaces(const TQString &platform);
private slots:
/** Runs the gst backend to get network values. You can pass to the script a specific platform to load using the platform parameter. */
- void runDetectionScript(QString platform);
+ void runDetectionScript(TQString platform);
void readIfconfigOutput();
void readNetworkInfo();
void readFromStdoutReloadScript();
/** emits a signal when the network changes have benn saved. */
void sendNetworkInfoSavedSignalSlot();
/** Concatenates into a QString the xml output of the network backend. */
void concatXMLOutputSlot();
void readXMLErrSlot();
/** Shows the dialog with all the supported platforms by GST. */
@@ -109,56 +109,56 @@ class KNetworkConfigParser : public QObject {
void processExitedSlot();
private:
- //QPtrList<KNetworkInterface> deviceList;
- QPtrList<KNetworkInterface> tempList;
+ //TQPtrList<KNetworkInterface> deviceList;
+ TQPtrList<KNetworkInterface> tempList;
KNetworkInterface *newDevice;
bool isUp;
/** Counts the number of configured devices that had been found. */
unsigned _numDevices;
KRoutingInfo *routingInfo;
KDNSInfo *dnsInfo;
- QString programVersion;
+ TQString programVersion;
/** The output of ifconfig command that needs to be parsed in readIfconfigOutput()*/
- QString ifconfigOutput;
+ TQString ifconfigOutput;
KNetworkInfo * networkInfo;
- QPtrList<KKnownHostInfo> knownHostsList;
- QString hexIPv4ToDecIPv4(const QString &hex);
+ TQPtrList<KKnownHostInfo> knownHostsList;
+ TQString hexIPv4ToDecIPv4(const TQString &hex);
/** lists all platforms supported by GST. */
void loadSupportedPlatforms();
/** Returns the info of a platform in the form of 'key:value' . */
- QString getPlatformInfo(QDomElement platform);
+ TQString getPlatformInfo(TQDomElement platform);
/** save process is running */
bool processRunning;
/** Shows a progress dialog while the networl is being reloaded. */
KInterfaceUpDownDlg * kpdReloadStatusDlg;
- QProcess *procReloadNetwork;
- QString reloadScriptOutput;
+ TQProcess *procReloadNetwork;
+ TQString reloadScriptOutput;
/** Contains the network configuration en xml format. */
/** List of supported platforms. */
- QStringList supportedPlatformsList;
- QString xmlOuput;
- QString xmlErr;
+ TQStringList supportedPlatformsList;
+ TQString xmlOuput;
+ TQString xmlErr;
/** Temporal device list to be used when loading the dhcp devices info */
- QPtrList<KNetworkInterface> tempDevList;
+ TQPtrList<KNetworkInterface> tempDevList;
/** Parses all of the <statichost>...</statichost> entries in the xml configuration file. */
- KKnownHostInfo * getStaticHostInfo(QDomElement host);
+ KKnownHostInfo * getStaticHostInfo(TQDomElement host);
/** Saves the option to show again or not the platform using KSimpleConfig*/
- void saveAskAgain(const QString &platform, bool askAgain);
+ void saveAskAgain(const TQString &platform, bool askAgain);
/**Returns if the show platform should be shown again or not and the saved platform*/
- bool readAskAgain(QString &platform);
- void parseNetworkInfo(QDomNode node, KNetworkInfo *networkInfo, bool isProfile);
- void addRoutingInfoToXMLDoc(QDomDocument *doc, QDomNode *root, KRoutingInfo *routingInfo);
- void addDNSInfoToXMLDoc(QDomDocument *doc, QDomNode *root, KDNSInfo *dnsInfo);
- void addNetworkInterfacesToXMLDoc(QDomDocument *doc, QDomNode *root, QPtrList<KNetworkInterface> devList);
- void addNetworkProfilesToXMLDoc(QDomDocument *doc, QDomNode *root, QPtrList<KNetworkInfo> profileList);
+ bool readAskAgain(TQString &platform);
+ void parseNetworkInfo(TQDomNode node, KNetworkInfo *networkInfo, bool isProfile);
+ void addRoutingInfoToXMLDoc(TQDomDocument *doc, TQDomNode *root, KRoutingInfo *routingInfo);
+ void addDNSInfoToXMLDoc(TQDomDocument *doc, TQDomNode *root, KDNSInfo *dnsInfo);
+ void addNetworkInterfacesToXMLDoc(TQDomDocument *doc, TQDomNode *root, TQPtrList<KNetworkInterface> devList);
+ void addNetworkProfilesToXMLDoc(TQDomDocument *doc, TQDomNode *root, TQPtrList<KNetworkInfo> profileList);
protected: // Protected methods
/** Parses all of the <interface>...</interface> entries in the xml configuration file. */
- virtual KNetworkInterface *getInterfaceInfo(QDomElement interface, const QString &type);
+ virtual KNetworkInterface *getInterfaceInfo(TQDomElement interface, const TQString &type);
/** Parses all of the <interface>...</interface> entries in the xml configuration file. Returns a KWirelessInterface
object that contains all the info of the wireless interface. */
- virtual KWirelessInterface *getWirelessInterfaceInfo(QDomElement interface, const QString &type);
+ virtual KWirelessInterface *getWirelessInterfaceInfo(TQDomElement interface, const TQString &type);
signals: // Signals
/** emmited when the xml file is finished reading. */
@@ -72,28 +72,28 @@ class KNetworkConfigParser : public QObject {
/** emits a signal when the network changes have benn saved. */
void sendNetworkInfoSavedSignalSlot();
- /** Concatenates into a QString the xml output of the network backend. */
+ /** Concatenates into a TQString the xml output of the network backend. */
void concatXMLOutputSlot();
void readXMLErrSlot();